summaryrefslogtreecommitdiffstats
path: root/src/usr
diff options
context:
space:
mode:
authorStephen Beaver <sbeaver@netgate.com>2015-11-06 14:04:45 -0500
committerStephen Beaver <sbeaver@netgate.com>2015-11-06 14:04:45 -0500
commita0fb2268f3efb40aabe544bb5a970c627d8d8f6b (patch)
treedb3ba4ba3beb9038a917fd0a310e8f6b3feeb674 /src/usr
parent121e5cacd4c55472c9975efe0f0d0a7b075ca1a8 (diff)
downloadpfsense-a0fb2268f3efb40aabe544bb5a970c627d8d8f6b.zip
pfsense-a0fb2268f3efb40aabe544bb5a970c627d8d8f6b.tar.gz
Fix cosmetic infoblock issue when there is more than one info_box on a page
Diffstat (limited to 'src/usr')
-rw-r--r--src/usr/local/www/jquery/pfSenseHelpers.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/usr/local/www/jquery/pfSenseHelpers.js b/src/usr/local/www/jquery/pfSenseHelpers.js
index 8ffca5c..9ba9135 100644
--- a/src/usr/local/www/jquery/pfSenseHelpers.js
+++ b/src/usr/local/www/jquery/pfSenseHelpers.js
@@ -371,8 +371,8 @@ $('[id^=delete]').click(function(event) {
if($('#infoblock').length != 0) {
$('#infoblock').before('<i class="fa fa-info-circle icon-pointer" style="color: #337AB7;; font-size:20px; margin-left: 10px; margin-bottom: 10px;" id="showinfo" title="More information"></i>');
- // and remove the 'X' button from the text box
- $('.close').remove();
+ // and remove the 'X' button from the last text box (Which we assume to be the infoblock)
+ $('.close :last').remove();
}
// Hide information on page load
OpenPOWER on IntegriCloud